Crate bort_vk

Crate bort_vk 

Re-exports

pub use raw_window_handle_06 as raw_window_handle;

Structs

ApiVersion
Buffer
Contains a VkBuffer and a memory allocation.
BufferProperties
Note: default values for size, and usage are nothing!
ColorBlendState
https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineColorBlendAttachmentState.html
CommandBuffer
CommandPool
CommandPoolProperties
Note: default value for queue_family_index is nothing!
ComputePipeline
ComputePipelineProperties
DebugCallback
DebugCallbackProperties
DepthStencilState
https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineDepthStencilStateCreateInfo.html
DescriptorPool
DescriptorPoolProperties
Note: default values are nothing!
DescriptorSet
DescriptorSetLayout
DescriptorSetLayoutBinding
Note: default values are nothing!
DescriptorSetLayoutProperties
Note: default has no bindings!
Device
DynamicState
https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineDynamicStateCreateInfo.html
ExtensionProperties
Properties of an extension in the loader or a physical device.
Fence
Framebuffer
FramebufferProperties
GraphicsPipeline
GraphicsPipelineProperties
https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkGraphicsPipelineCreateInfo.html
GraphicsPipelinePropertiesCreateInfosVk
The equivilent vk*CreateInfo structs for the members of GraphicsPipelineProperties.
Image
ImageProperties
Note: default values for format, dimensions and usage are nothing!
ImageView
ImageViewProperties
WARNING default() values for format, view_type are nothing!
InputAssemblyState
https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineInputAssemblyStateCreateInfo.html
Instance
MemoryAllocation
Note this doesn’t impl Drop. Destroy this yourself! e.g. with Buffer and Image Drop implementations
MemoryAllocator
MemoryPool
MemoryPoolPropeties
MultisampleState
https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineMultisampleStateCreateInfo.html
PerPipelineCreationParams
Per-pipeline creation arguments
PhysicalDevice
PipelineCache
PipelineLayout
PipelineLayoutProperties
Queue
RasterizationState
https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineRasterizationStateCreateInfo.html
RenderPass
RenderPassProperties
Sampler
SamplerProperties
Semaphore
ShaderModule
ShaderStage
Subpass
Surface
Swapchain
SwapchainImage
SwapchainProperties
WARNING when using default() the following values should be overridden:
TessellationState
https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineTessellationStateCreateInfo.html
VertexInputState
https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineVertexInputStateCreateInfo.html
ViewportState
https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineViewportStateCreateInfo.html

Enums

CommandError
DeviceError
ImageAccessError
ImageDimensions
InstanceError
MemoryError
PhysicalDeviceError
QueueError
ShaderError
SurfaceCreationError
SwapchainError

Constants

ALLOCATION_CALLBACK_NONE
so it’s easy to find all allocation callback args, just in case I want to use them in the future.

Traits

AllocationAccess
Allows any struct containing a memory allocation to “inherit” the read/write functions
AllocatorAccess
Unifies different types of vma allocators
DeviceOwned
ImageAccess
Unifies different types of images
ImageViewAccess
Unifies image views with different types of images
PipelineAccess
Unifies different types of pipeline

Functions

allocation_info_cpu_accessible
For allocating memory that can be accessed and mapped from the cpu. Prefered flags include HOST_COHERENT (doesn’t require flushing). Good for staging buffers.
allocation_info_from_flags
Default AllocationCreateInfo with specified required and preferred flags.
aspect_mask_from_format
Doesn’t support planes/metadata.
c_string_to_string
Safety: see CStr::from_ptr documentation…
choose_composite_alpha
Checks surface support for the first compositie alpha flag in order of preference:
default_component_mapping
default_subresource_layers
default_subresource_range
extent_2d_from_width_height
get_first_linear_surface_format
Returns the first surface format with a linear image format in the vec. Returns None is there’s none.
get_first_srgb_surface_format
Returns the first surface format with a linear image format in the vec. Returns None is there’s none.
guaranteed_depth_stencil_format
Returns a depth stencil format guarenteed by the vulkan spec to be supported as a depth stencil attachment. Prefers VK_FORMAT_D24_UNORM_S8_UINT.
guaranteed_pure_depth_format
Returns a pure depth format guarenteed by the vulkan spec to be supported as a depth stencil attachment. Prefers VK_FORMAT_D32_SFLOAT.
is_format_linear
is_format_srgb
transient_image_info
Properties for a device local and preferably lazily-allocated transient attachment image.