pub struct ColorBlendState {
pub flags: PipelineColorBlendStateCreateFlags,
pub logic_op: Option<LogicOp>,
pub attachments: Vec<PipelineColorBlendAttachmentState>,
pub blend_constants: [f32; 4],
}Expand description
Fields
flags: PipelineColorBlendStateCreateFlagslogic_op: Option<LogicOp>attachments: Vec<PipelineColorBlendAttachmentState>blend_constants: [f32; 4]Implementations
Sourceimpl ColorBlendState
impl ColorBlendState
pub fn new_default(attachments: Vec<PipelineColorBlendAttachmentState>) -> Self
pub fn write_create_info_builder<'a>( &'a self, builder: PipelineColorBlendStateCreateInfoBuilder<'a>, ) -> PipelineColorBlendStateCreateInfoBuilder<'a>
pub fn create_info_builder( &self, ) -> PipelineColorBlendStateCreateInfoBuilder<'_>
pub fn blend_state_disabled() -> PipelineColorBlendAttachmentState
Sourcepub fn blend_state_ignore_source() -> PipelineColorBlendAttachmentState
pub fn blend_state_ignore_source() -> PipelineColorBlendAttachmentState
Returns vk::PipelineColorBlendAttachmentState where the output of the fragment shader is ignored and the
destination is untouched.
Sourcepub fn blend_state_additive() -> PipelineColorBlendAttachmentState
pub fn blend_state_additive() -> PipelineColorBlendAttachmentState
Returns vk::PipelineColorBlendAttachmentState where the colors are added, and alpha is set to the maximum of
the two.
Sourcepub unsafe fn from_create_info(
value: &PipelineColorBlendStateCreateInfo,
) -> Self
pub unsafe fn from_create_info( value: &PipelineColorBlendStateCreateInfo, ) -> Self
Safety:
- if
p_attachmentsis not null, it must point to an array ofattachment_countvalues
pub fn from_create_info_builder( value: &PipelineColorBlendStateCreateInfoBuilder<'_>, ) -> Self