GraphicsPipelineProperties

Struct GraphicsPipelineProperties 

pub struct GraphicsPipelineProperties {
    pub flags: PipelineCreateFlags,
    pub subpass_index: u32,
    pub vertex_input_state: VertexInputState,
    pub input_assembly_state: InputAssemblyState,
    pub tessellation_state: TessellationState,
    pub viewport_state: ViewportState,
    pub rasterization_state: RasterizationState,
    pub multisample_state: MultisampleState,
    pub depth_stencil_state: DepthStencilState,
    pub color_blend_state: ColorBlendState,
    pub dynamic_state: DynamicState,
}
https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkGraphicsPipelineCreateInfo.html

Note: doesn’t include shader stages, render pass, pipeline layout or pipeline cache

Fields

flags: PipelineCreateFlagssubpass_index: u32vertex_input_state: VertexInputStateinput_assembly_state: InputAssemblyStatetessellation_state: TessellationStateviewport_state: ViewportStaterasterization_state: RasterizationStatemultisample_state: MultisampleStatedepth_stencil_state: DepthStencilStatecolor_blend_state: ColorBlendStatedynamic_state: DynamicState

Implementations

Source

impl GraphicsPipelineProperties

pub fn write_create_info_builder<'a>( &'a self, builder: GraphicsPipelineCreateInfoBuilder<'a>, properties_vk: &'a GraphicsPipelinePropertiesCreateInfosVk<'a>, ) -> GraphicsPipelineCreateInfoBuilder<'a>

Returns the builder arg containing references to the structs in properties_vk.

Note: this doesn’t populate:

  • layout
  • render_pass
  • subpass
  • stages
  • base_pipeline_handle
  • base_pipeline_index
pub fn vk_create_infos<'a>( &'a self, ) -> GraphicsPipelinePropertiesCreateInfosVk<'a>

Returns a set of vk::*CreateInfoBuilder structs populated by the members of self. Use this with Self::write_create_info_builder to populate a GraphicsPipelineCreateInfoBuilder.

pub unsafe fn from_create_info(value: &GraphicsPipelineCreateInfo) -> Self

Safety:

  • if any of the following members aren’t null they must point to something!
    • p_vertex_input_state
    • p_input_assembly_state
    • p_tessellation_state
    • p_viewport_state
    • p_rasterization_state
    • p_multisample_state
    • p_depth_stencil_state
    • p_color_blend_state
    • p_dynamic_state
  • see docs for the following functions for additional safety requirements:
    • [VertexInputState::from_create_info_ptr]
    • [ViewportState::from_create_info_ptr]
    • [MultisampleState::from_create_info_ptr]
    • [ColorBlendState::from_create_info_ptr]
    • [DynamicState::from_create_info_ptr]
pub unsafe fn from_create_info_builder( value: &GraphicsPipelineCreateInfoBuilder<'_>, ) -> Self