GraphicsPipelinePropertiesCreateInfosVk

Struct GraphicsPipelinePropertiesCreateInfosVk 

pub struct GraphicsPipelinePropertiesCreateInfosVk<'a> {
    pub vertex_input_state_vk: PipelineVertexInputStateCreateInfoBuilder<'a>,
    pub input_assembly_state_vk: PipelineInputAssemblyStateCreateInfoBuilder<'a>,
    pub tessellation_state_vk: PipelineTessellationStateCreateInfoBuilder<'a>,
    pub viewport_state_vk: PipelineViewportStateCreateInfoBuilder<'a>,
    pub rasterization_state_vk: PipelineRasterizationStateCreateInfoBuilder<'a>,
    pub multisample_state_vk: PipelineMultisampleStateCreateInfoBuilder<'a>,
    pub depth_stencil_state_vk: PipelineDepthStencilStateCreateInfoBuilder<'a>,
    pub color_blend_state_vk: PipelineColorBlendStateCreateInfoBuilder<'a>,
    pub dynamic_state_vk: PipelineDynamicStateCreateInfoBuilder<'a>,
}
The equivilent vk*CreateInfo structs for the members of GraphicsPipelineProperties.

These are populated in GraphicsPipelineProperties::vk_create_infos in order for the GraphicsPipelineCreateInfo to have references to create info structs whose lifetimes can be ensured to live for the duration of the builder.

Fields

vertex_input_state_vk: PipelineVertexInputStateCreateInfoBuilder<'a>input_assembly_state_vk: PipelineInputAssemblyStateCreateInfoBuilder<'a>tessellation_state_vk: PipelineTessellationStateCreateInfoBuilder<'a>viewport_state_vk: PipelineViewportStateCreateInfoBuilder<'a>rasterization_state_vk: PipelineRasterizationStateCreateInfoBuilder<'a>multisample_state_vk: PipelineMultisampleStateCreateInfoBuilder<'a>depth_stencil_state_vk: PipelineDepthStencilStateCreateInfoBuilder<'a>color_blend_state_vk: PipelineColorBlendStateCreateInfoBuilder<'a>dynamic_state_vk: PipelineDynamicStateCreateInfoBuilder<'a>