pub struct RenderPass { /* private fields */ }Implementations
Sourceimpl RenderPass
impl RenderPass
pub fn new( device: Arc<Device>, attachment_descriptions: Vec<AttachmentDescription>, subpasses: Vec<Subpass>, subpass_dependencies: Vec<SubpassDependency>, ) -> VkResult<Self>
Sourcepub unsafe fn new_from_create_info(
device: Arc<Device>,
create_info_builder: RenderPassCreateInfoBuilder<'_>,
) -> VkResult<Self>
pub unsafe fn new_from_create_info( device: Arc<Device>, create_info_builder: RenderPassCreateInfoBuilder<'_>, ) -> VkResult<Self>
Safety:
For each subpass:
- if
subpass_description.p_color_attachmentsis not null it must point to an array withsubpass_description.color_attachment_countmany elements. - if
subpass_description.p_input_attachmentsis not null it must point to an array withsubpass_description.input_attachment_countmany elements.
pub fn handle(&self) -> RenderPass
pub fn properties(&self) -> &RenderPassProperties