pub struct Subpass {
pub color_attachments: Vec<AttachmentReference>,
pub depth_attachment: Option<AttachmentReference>,
pub input_attachments: Vec<AttachmentReference>,
}Fields
color_attachments: Vec<AttachmentReference>depth_attachment: Option<AttachmentReference>input_attachments: Vec<AttachmentReference>Implementations
Sourceimpl Subpass
impl Subpass
pub fn new( color_attachments: &[AttachmentReference], depth_attachment: Option<AttachmentReference>, input_attachments: &[AttachmentReference], ) -> Self
pub fn from_subpass_description_builder( subpass_description: &SubpassDescriptionBuilder<'_>, ) -> Self
Sourcepub unsafe fn from_subpass_description(
subpass_description: &SubpassDescription,
) -> Self
pub unsafe fn from_subpass_description( subpass_description: &SubpassDescription, ) -> Self
Safety:
- if
subpass_description.p_color_attachmentsis not null it must point to an array withsubpass_description.color_attachment_countmany elements. - if
subpass_description.p_input_attachmentsis not null it must point to an array withsubpass_description.input_attachment_countmany elements.
pub fn subpass_description_builder(&self) -> SubpassDescriptionBuilder<'_>