pub struct VertexInputState {
pub flags: PipelineVertexInputStateCreateFlags,
pub vertex_binding_descriptions: Vec<VertexInputBindingDescription>,
pub vertex_attribute_descriptions: Vec<VertexInputAttributeDescription>,
}Expand description
Fields
flags: PipelineVertexInputStateCreateFlagsvertex_binding_descriptions: Vec<VertexInputBindingDescription>vertex_attribute_descriptions: Vec<VertexInputAttributeDescription>Implementations
Sourceimpl VertexInputState
impl VertexInputState
pub fn write_create_info_builder<'a>( &'a self, builder: PipelineVertexInputStateCreateInfoBuilder<'a>, ) -> PipelineVertexInputStateCreateInfoBuilder<'a>
pub fn create_info_builder( &self, ) -> PipelineVertexInputStateCreateInfoBuilder<'_>
Sourcepub unsafe fn from_create_info(
value: &PipelineVertexInputStateCreateInfo,
) -> Self
pub unsafe fn from_create_info( value: &PipelineVertexInputStateCreateInfo, ) -> Self
Safety:
- if
p_vertex_binding_descriptionsis not null, it must point to an array ofvertex_binding_description_countvalues - if
p_vertex_attribute_descriptionsis not null, it must point to an array ofvertex_attribute_description_countvalues
pub fn from_create_info_builder( value: &PipelineVertexInputStateCreateInfoBuilder<'_>, ) -> Self