pub struct ViewportState {
pub flags: PipelineViewportStateCreateFlags,
pub viewports: Vec<Viewport>,
pub scissors: Vec<Rect2D>,
}Expand description
Fields
flags: PipelineViewportStateCreateFlagsviewports: Vec<Viewport>scissors: Vec<Rect2D>Implementations
Sourceimpl ViewportState
impl ViewportState
pub fn new_dynamic(viewport_count: usize, scissor_count: usize) -> Self
pub fn write_create_info_builder<'a>( &'a self, builder: PipelineViewportStateCreateInfoBuilder<'a>, ) -> PipelineViewportStateCreateInfoBuilder<'a>
pub fn create_info_builder(&self) -> PipelineViewportStateCreateInfoBuilder<'_>
Sourcepub unsafe fn from_create_info(value: &PipelineViewportStateCreateInfo) -> Self
pub unsafe fn from_create_info(value: &PipelineViewportStateCreateInfo) -> Self
Safety:
- if
p_viewportsis not null, it must point to an array ofviewport_countvalues - if
p_scissorsis not null, it must point to an array ofscissor_countvalues
pub fn from_create_info_builder( value: &PipelineViewportStateCreateInfoBuilder<'_>, ) -> Self