Re-exports
pub use raw_window_handle_06 as raw_window_handle;
Structs
- ApiVersion
- Buffer
- Contains a VkBuffer and a memory allocation.
- Buffer
Properties - Note: default values for
size, andusageare nothing! - Color
Blend State - https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineColorBlendAttachmentState.html
- Command
Buffer - Command
Pool - Command
Pool Properties - Note: default value for
queue_family_indexis nothing! - Compute
Pipeline - Compute
Pipeline Properties - Debug
Callback - Debug
Callback Properties - Depth
Stencil State - https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineDepthStencilStateCreateInfo.html
- Descriptor
Pool - Descriptor
Pool Properties - Note: default values are nothing!
- Descriptor
Set - Descriptor
SetLayout - Descriptor
SetLayout Binding - Note: default values are nothing!
- Descriptor
SetLayout Properties - Note: default has no bindings!
- Device
- Dynamic
State - https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineDynamicStateCreateInfo.html
- Extension
Properties - Properties of an extension in the loader or a physical device.
- Fence
- Framebuffer
- Framebuffer
Properties - Graphics
Pipeline - Graphics
Pipeline Properties - https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkGraphicsPipelineCreateInfo.html
- Graphics
Pipeline Properties Create Infos Vk - The equivilent vk*CreateInfo structs for the members of
GraphicsPipelineProperties. - Image
- Image
Properties - Note: default values for
format,dimensionsandusageare nothing! - Image
View - Image
View Properties - WARNING
default()values forformat,view_typeare nothing! - Input
Assembly State - https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineInputAssemblyStateCreateInfo.html
- Instance
- Memory
Allocation - Note this doesn’t impl
Drop. Destroy this yourself! e.g. withBufferandImageDropimplementations - Memory
Allocator - Memory
Pool - Memory
Pool Propeties - Multisample
State - https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineMultisampleStateCreateInfo.html
- PerPipeline
Creation Params - Per-pipeline creation arguments
- Physical
Device - Pipeline
Cache - Pipeline
Layout - Pipeline
Layout Properties - Queue
- Rasterization
State - https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineRasterizationStateCreateInfo.html
- Render
Pass - Render
Pass Properties - Sampler
- Sampler
Properties - Semaphore
- Shader
Module - Shader
Stage - Subpass
- Surface
- Swapchain
- Swapchain
Image - Swapchain
Properties - WARNING when using
default()the following values should be overridden: - Tessellation
State - https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineTessellationStateCreateInfo.html
- Vertex
Input State - https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineVertexInputStateCreateInfo.html
- Viewport
State - https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/VkPipelineViewportStateCreateInfo.html
Enums
- Command
Error - Device
Error - Image
Access Error - Image
Dimensions - Instance
Error - Memory
Error - Physical
Device Error - Queue
Error - Shader
Error - Surface
Creation Error - Swapchain
Error
Constants
- ALLOCATION_
CALLBACK_ NONE - so it’s easy to find all allocation callback args, just in case I want to use them in the future.
Traits
- Allocation
Access - Allows any struct containing a memory allocation to “inherit” the read/write functions
- Allocator
Access - Unifies different types of vma allocators
- Device
Owned - Image
Access - Unifies different types of images
- Image
View Access - Unifies image views with different types of images
- Pipeline
Access - Unifies different types of pipeline
Functions
- allocation_
info_ cpu_ accessible - For allocating memory that can be accessed and mapped from the cpu. Prefered flags include HOST_COHERENT (doesn’t require flushing). Good for staging buffers.
- allocation_
info_ from_ flags - Default
AllocationCreateInfowith specified required and preferred flags. - aspect_
mask_ from_ format - Doesn’t support planes/metadata.
- c_
string_ ⚠to_ string - Safety: see
CStr::from_ptrdocumentation… - choose_
composite_ alpha - Checks surface support for the first compositie alpha flag in order of preference:
- default_
component_ mapping - default_
subresource_ layers - default_
subresource_ range - extent_
2d_ from_ width_ height - get_
first_ linear_ surface_ format - Returns the first surface format with a linear image format in the vec. Returns
Noneis there’s none. - get_
first_ srgb_ surface_ format - Returns the first surface format with a linear image format in the vec. Returns
Noneis there’s none. - guaranteed_
depth_ stencil_ format - Returns a depth stencil format guarenteed by the vulkan spec to be supported as a depth stencil attachment. Prefers VK_FORMAT_D24_UNORM_S8_UINT.
- guaranteed_
pure_ depth_ format - Returns a pure depth format guarenteed by the vulkan spec to be supported as a depth stencil attachment. Prefers VK_FORMAT_D32_SFLOAT.
- is_
format_ linear - is_
format_ srgb - transient_
image_ info - Properties for a device local and preferably lazily-allocated transient attachment image.