pub struct GraphicsPipelineProperties {
pub flags: PipelineCreateFlags,
pub subpass_index: u32,
pub vertex_input_state: VertexInputState,
pub input_assembly_state: InputAssemblyState,
pub tessellation_state: TessellationState,
pub viewport_state: ViewportState,
pub rasterization_state: RasterizationState,
pub multisample_state: MultisampleState,
pub depth_stencil_state: DepthStencilState,
pub color_blend_state: ColorBlendState,
pub dynamic_state: DynamicState,
}Expand description
Note: doesn’t include shader stages, render pass, pipeline layout or pipeline cache
Fields
flags: PipelineCreateFlagssubpass_index: u32vertex_input_state: VertexInputStateinput_assembly_state: InputAssemblyStatetessellation_state: TessellationStateviewport_state: ViewportStaterasterization_state: RasterizationStatemultisample_state: MultisampleStatedepth_stencil_state: DepthStencilStatecolor_blend_state: ColorBlendStatedynamic_state: DynamicStateImplementations
Sourceimpl GraphicsPipelineProperties
impl GraphicsPipelineProperties
Sourcepub fn write_create_info_builder<'a>(
&'a self,
builder: GraphicsPipelineCreateInfoBuilder<'a>,
properties_vk: &'a GraphicsPipelinePropertiesCreateInfosVk<'a>,
) -> GraphicsPipelineCreateInfoBuilder<'a>
pub fn write_create_info_builder<'a>( &'a self, builder: GraphicsPipelineCreateInfoBuilder<'a>, properties_vk: &'a GraphicsPipelinePropertiesCreateInfosVk<'a>, ) -> GraphicsPipelineCreateInfoBuilder<'a>
Returns the builder arg containing references to the structs in properties_vk.
Note: this doesn’t populate:
layoutrender_passsubpassstagesbase_pipeline_handlebase_pipeline_index
Sourcepub fn vk_create_infos<'a>(
&'a self,
) -> GraphicsPipelinePropertiesCreateInfosVk<'a>
pub fn vk_create_infos<'a>( &'a self, ) -> GraphicsPipelinePropertiesCreateInfosVk<'a>
Returns a set of vk::*CreateInfoBuilder structs populated by the members of self.
Use this with Self::write_create_info_builder to populate a GraphicsPipelineCreateInfoBuilder.
Sourcepub unsafe fn from_create_info(value: &GraphicsPipelineCreateInfo) -> Self
pub unsafe fn from_create_info(value: &GraphicsPipelineCreateInfo) -> Self
Safety:
- if any of the following members aren’t null they must point to something!
p_vertex_input_statep_input_assembly_statep_tessellation_statep_viewport_statep_rasterization_statep_multisample_statep_depth_stencil_statep_color_blend_statep_dynamic_state
- see docs for the following functions for additional safety requirements:
- [
VertexInputState::from_create_info_ptr] - [
ViewportState::from_create_info_ptr] - [
MultisampleState::from_create_info_ptr] - [
ColorBlendState::from_create_info_ptr] - [
DynamicState::from_create_info_ptr]
- [
Sourcepub unsafe fn from_create_info_builder(
value: &GraphicsPipelineCreateInfoBuilder<'_>,
) -> Self
pub unsafe fn from_create_info_builder( value: &GraphicsPipelineCreateInfoBuilder<'_>, ) -> Self
Safety requirements found in docs for the following: